@@ -1,6 +1,5 @@
 # pylint: disable=invalid-name,redefined-builtin
 
-import os
 
 extensions = [
     "sphinx.ext.autodoc",
@@ -19,7 +18,7 @@ project = "pre-commit-vauxoo"
 year = "2022"
 author = "Vauxoo"
 copyright = "{}, {}".format(year, author)
-version = release = "7.0.17"
+version = release = "8.0.2"
 
 pygments_style = "trac"
 templates_path = ["."]
@@ -27,12 +26,8 @@ extlinks = {
     "issue": ("https://github.com/Vauxoo/pre-commit-vauxoo/issues/%s", "#"),
     "pr": ("https://github.com/Vauxoo/pre-commit-vauxoo/pull/%s", "PR #"),
 }
-# on_rtd is whether we are on readthedocs.org
-on_rtd = os.environ.get("READTHEDOCS", None) == "True"
-
-if not on_rtd:  # only set the theme if we're building docs locally
-    html_theme = "sphinx_rtd_theme"
 
+html_theme = "sphinx_rtd_theme"
 html_use_smartypants = True
 html_last_updated_fmt = "%b %d, %Y"
 html_split_index = False
