@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import logging
 import os
 import posixpath
@@ -7,10 +9,13 @@ import subprocess
 import sys
 import tempfile
 import unittest
-from contextlib import contextmanager
+from configparser import ConfigParser
+from contextlib import contextmanager, redirect_stdout
 from distutils.dir_util import copy_tree  # pylint:disable=deprecated-module
+from io import StringIO
 
 from click.testing import CliRunner
+from pylint.lint import Run
 from yaml import Loader, load
 
 from pre_commit_vauxoo.cli import main
@@ -21,7 +26,7 @@ class TestPreCommitVauxoo(unittest.TestCase):
         super().setUp()
         self.old_environ = os.environ.copy()
         self.original_work_dir = os.getcwd()
-        self.tmp_dir = tempfile.mkdtemp(suffix="_pre_commit_vauxoo")
+        self.tmp_dir = os.path.realpath(tempfile.mkdtemp(suffix="_pre_commit_vauxoo"))
         os.chdir(self.tmp_dir)
         self.runner = CliRunner()
         src_path = os.path.join(os.path.dirname(os.path.dirname(os.path.realpath(__file__))), "resources")
@@ -70,6 +75,16 @@ class TestPreCommitVauxoo(unittest.TestCase):
             # bypassing for dual compatibility with py<3.4
             yield
 
+    def get_pylint_messages(self):
+        output = StringIO()
+        with self.assertRaises(SystemExit) as ex, redirect_stdout(output):
+            Run(["--load-plugins=pylint.extensions.docstyle,pylint.extensions.mccabe,pylint_odoo", "--list-msgs"])
+        self.assertEqual(ex.exception.code, 0, "There was an error obtaining messages from pylint")
+
+        output.seek(0)
+        output = output.read()
+        return set(re.findall(r"^:([a-z\-]+)", output, re.MULTILINE))
+
     def test_basic(self):
         os.environ["INCLUDE_LINT"] = os.path.join(self.tmp_dir, "module_example1")
         os.environ["PRECOMMIT_HOOKS_TYPE"] = "all"
@@ -79,7 +94,6 @@ class TestPreCommitVauxoo(unittest.TestCase):
             self.assertIn("skip-string-normalization=false", f_pyproject.read(), "Skip string normalization not set")
 
     def test_chdir(self):
-        self.runner = CliRunner()
         os.environ["PRECOMMIT_HOOKS_TYPE"] = "all"
         os.chdir("module_autofix1")
         expected_logs = ["WARNING:pre-commit-vauxoo:Running in current directory 'module_autofix1'"]
@@ -89,8 +103,6 @@ class TestPreCommitVauxoo(unittest.TestCase):
         self.assertEqual(result.exit_code, 0, "Exited with error %s - %s" % (result, result.output))
 
     def test_exclude_lint_path(self):
-        self.runner = CliRunner()
-
         os.environ["PRECOMMIT_HOOKS_TYPE"] = "all"
         os.environ["BLACK_SKIP_STRING_NORMALIZATION"] = "false"
         os.environ["EXCLUDE_LINT"] = "module_example1/models"
@@ -101,7 +113,6 @@ class TestPreCommitVauxoo(unittest.TestCase):
         self.assertIn("skip-string-normalization=false", f_content, "Skip string normalization not set")
 
     def test_disable_lints(self):
-        self.runner = CliRunner()
         os.environ["DISABLE_PYLINT_CHECKS"] = "import-error"
         result = self.runner.invoke(main, [])
         self.assertEqual(result.exit_code, 0, "Exited with error %s - %s" % (result, result.output))
@@ -110,8 +121,6 @@ class TestPreCommitVauxoo(unittest.TestCase):
         self.assertIn("import-error,", f_content, "import-error was not disabled")
 
     def test_exclude_autofix(self):
-        self.runner = CliRunner()
-
         os.environ["PRECOMMIT_HOOKS_TYPE"] = "all"
         os.environ["EXCLUDE_AUTOFIX"] = "module_example1/demo/"
         os.environ["BLACK_SKIP_STRING_NORMALIZATION"] = "true"
@@ -198,6 +207,40 @@ class TestPreCommitVauxoo(unittest.TestCase):
         self.assertTrue(pattern.search(posixpath.join(repo_path, "models", "res_partner.py")))
         self.assertIsNone(pattern.search(posixpath.join(repo_sub_path, "wizard", "invoice_send.py")))
 
+    def test_disable_oca_hooks(self):
+        os.environ["OCA_HOOKS_DISABLE_CHECKS"] = "random-message"
+        self.runner.invoke(main, [])
+        with open(os.path.join(self.tmp_dir, ".oca_hooks.cfg")) as hooks_cfg:
+            f_content = hooks_cfg.read()
+        self.assertIn(
+            "disable=xml-oe-structure-missing-id,po-pretty-format,random-message",
+            f_content,
+            "random-message was supposed to be disabled through the corresponding environment variable",
+        )
+
+    def test_valid_pylintrc_messages(self):
+        pylint_messages = self.get_pylint_messages()
+        rc_files = [
+            os.path.abspath(os.path.join(__file__, "..", "..", "src", "pre_commit_vauxoo", "cfg", pylintrc))
+            for pylintrc in [".pylintrc", ".pylintrc-optional"]
+        ]
+        for rc_file in rc_files:
+            config = ConfigParser()
+            config.read(rc_file)
+            for action in ["enable", "disable"]:
+                if config["MESSAGES CONTROL"][action] == "all":
+                    continue
+
+                messages = config["MESSAGES CONTROL"][action].split(",\n")
+                duplicates = set()
+                messages_set = set()
+                for message in messages:
+                    self.assertIn(message, pylint_messages, f"{message} in {rc_file} is not a valid message")
+                    self.assertNotIn(message, messages_set, f"Duplicate '{message}' in {rc_file}")
+                    messages_set.add(message)
+
+                self.assertFalse(duplicates, f"Duplicate messages found in {rc_file}")
+
 
 if __name__ == "__main__":
     unittest.main()
